@@ -31,6 +31,8 @@ const maxFileSize = 1024 * 1024 * 512
 
 var (
 	composeFile              string
+	buildpacksBuilder        string
+	defaultKustomization     string
 	cliArtifacts             []string
 	cliKubernetesManifests   []string
 	skipBuild                bool
@@ -42,7 +44,6 @@ var (
 	enableBuildpacksInit     bool
 	enableNewInitFormat      bool
 	enableManifestGeneration bool
-	buildpacksBuilder        string
 )
 
 // for testing
@@ -59,8 +60,9 @@ func NewCmdInit() *cobra.Command {
 			f.MarkHidden("skip-deploy")
 			f.BoolVar(&force, "force", false, "Force the generation of the Skaffold config")
 			f.StringVar(&composeFile, "compose-file", "", "Initialize from a docker-compose file")
+			f.StringVar(&defaultKustomization, "default-kustomization", "", "Default Kustomization overlay path (others will be added as profiles)")
 			f.StringArrayVarP(&cliArtifacts, "artifact", "a", nil, "'='-delimited Dockerfile/image pair, or JSON string, to generate build artifact\n(example: --artifact='{\"builder\":\"Docker\",\"payload\":{\"path\":\"/web/Dockerfile.web\"},\"image\":\"gcr.io/web-project/image\"}')")
-			f.StringArrayVarP(&cliKubernetesManifests, "kubernetes-manifest", "k", nil, "a path or a glob pattern to kubernetes manifests (can be non-existent) to be added to the kubectl deployer (overrides detection of kubernetes manifests). Repeat the flag for multiple entries. E.g.: skaffold init -k pod.yaml -k k8s/*.yml")
+			f.StringArrayVarP(&cliKubernetesManifests, "kubernetes-manifest", "k", nil, "A path or a glob pattern to kubernetes manifests (can be non-existent) to be added to the kubectl deployer (overrides detection of kubernetes manifests). Repeat the flag for multiple entries. E.g.: skaffold init -k pod.yaml -k k8s/*.yml")
 			f.BoolVar(&analyze, "analyze", false, "Print all discoverable Dockerfiles and images in JSON format to stdout")
 			f.BoolVar(&enableNewInitFormat, "XXenableNewInitFormat", false, "")
 			f.MarkHidden("XXenableNewInitFormat")
@@ -80,7 +82,9 @@ func NewCmdInit() *cobra.Command {
 
 func doInit(ctx context.Context, out io.Writer) error {
 	return initEntrypoint(ctx, out, config.Config{
+		BuildpacksBuilder:        buildpacksBuilder,
 		ComposeFile:              composeFile,
+		DefaultKustomization:     defaultKustomization,
 		CliArtifacts:             cliArtifacts,
 		CliKubernetesManifests:   cliKubernetesManifests,
 		SkipBuild:                skipBuild,
@@ -92,7 +96,6 @@ func doInit(ctx context.Context, out io.Writer) error {
 		EnableBuildpacksInit:     enableBuildpacksInit,
 		EnableNewInitFormat:      enableNewInitFormat || enableBuildpacksInit || enableJibInit,
 		EnableManifestGeneration: enableManifestGeneration,
-		BuildpacksBuilder:        buildpacksBuilder,
 		Opts:                     opts,
 		MaxFileSize:              maxFileSize,
 	})
