@@ -133,9 +133,7 @@ func TestDevAPITriggers(t *testing.T) {
 }
 
 func TestDevAPIAutoTriggers(t *testing.T) {
-	if testing.Short() || RunOnGCP() {
-		t.Skip("skipping kind integration test")
-	}
+	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	Run(t, "testdata/dev", "sh", "-c", "echo foo > foo")
 	defer Run(t, "testdata/dev", "rm", "foo")
@@ -356,6 +354,9 @@ func createModifiedKubeconfig(namespace string) ([]byte, string, error) {
 	if config.IsKindCluster(kubeConfig.CurrentContext) {
 		contextName = "kind-" + contextName
 	}
+	if config.IsK3dCluster(kubeConfig.CurrentContext) {
+		contextName = "k3d-" + contextName
+	}
 
 	if kubeConfig.CurrentContext == constants.DefaultMinikubeContext {
 		contextName = constants.DefaultMinikubeContext // skip, since integration test with minikube runs on single cluster
