@@ -33,6 +33,7 @@ func TestJdwpTransformer_IsApplicable(t *testing.T) {
 	tests := []struct {
 		description string
 		source      imageConfiguration
+		launcher    string
 		result      bool
 	}{
 		{
@@ -65,6 +66,12 @@ func TestJdwpTransformer_IsApplicable(t *testing.T) {
 			source:      imageConfiguration{arguments: []string{"/usr/bin/java", "-jar", "foo.jar"}},
 			result:      true,
 		},
+		{
+			description: "launcher entrypoint",
+			source:      imageConfiguration{entrypoint: []string{"launcher"}, arguments: []string{"/usr/bin/java", "-jar", "foo.jar"}},
+			launcher:    "launcher",
+			result:      true,
+		},
 		{
 			description: "entrypoint /bin/sh",
 			source:      imageConfiguration{entrypoint: []string{"/bin/sh"}},
@@ -78,6 +85,7 @@ func TestJdwpTransformer_IsApplicable(t *testing.T) {
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
+			t.Override(&entrypointLaunchers, []string{test.launcher})
 			result := jdwpTransformer{}.IsApplicable(test.source)
 
 			t.CheckDeepEqual(test.result, result)
@@ -497,7 +505,7 @@ func TestTransformManifestJVM(t *testing.T) {
 			retriever := func(image string) (imageConfiguration, error) {
 				return imageConfiguration{}, nil
 			}
-			result := transformManifest(value, retriever)
+			result := transformManifest(value, retriever, "HELPERS")
 
 			t.CheckDeepEqual(test.transformed, result)
 			t.CheckDeepEqual(test.out, value)
