@@ -19,8 +19,10 @@ package docker
 import (
 	"errors"
 	"fmt"
+	"os/exec"
 	"testing"
 
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/cluster"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
@@ -66,7 +68,7 @@ func TestNewMinikubeImageAPIClient(t *testing.T) {
 	}{
 		{
 			description: "correct client",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST=http://127.0.0.1:8080
 DOCKER_CERT_PATH=testdata
 DOCKER_API_VERSION=1.23`),
@@ -74,7 +76,7 @@ DOCKER_API_VERSION=1.23`),
 		},
 		{
 			description: "correct client - work around minikube #8615",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST=http://127.0.0.1:8080
 DOCKER_CERT_PATH=testdata
 DOCKER_API_VERSION=1.23
@@ -86,7 +88,7 @@ DOCKER_API_VERSION=1.23
 		},
 		{
 			description: "bad certificate",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST=http://127.0.0.1:8080
 DOCKER_CERT_PATH=bad/cert/path
 DOCKER_API_VERSION=1.23`),
@@ -94,21 +96,21 @@ DOCKER_API_VERSION=1.23`),
 		},
 		{
 			description: "missing host env, no error",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_CERT_PATH=testdata
 DOCKER_API_VERSION=1.23`),
 			expectedEnv: []string{"DOCKER_API_VERSION=1.23", "DOCKER_CERT_PATH=testdata", "DOCKER_TLS_VERIFY=1"},
 		},
 		{
 			description: "missing version env, no error",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST=http://127.0.0.1:8080
 DOCKER_CERT_PATH=testdata`),
 			expectedEnv: []string{"DOCKER_CERT_PATH=testdata", "DOCKER_HOST=http://127.0.0.1:8080", "DOCKER_TLS_VERIFY=1"},
 		},
 		{
 			description: "bad url",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST=badurl
 DOCKER_CERT_PATH=testdata
 DOCKER_API_VERSION=1.23`),
@@ -116,7 +118,7 @@ DOCKER_API_VERSION=1.23`),
 		},
 		{
 			description: "allow `=` in urls",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST=http://127.0.0.1:8080?k=v
 DOCKER_CERT_PATH=testdata
 DOCKER_API_VERSION=1.23`),
@@ -124,25 +126,26 @@ DOCKER_API_VERSION=1.23`),
 		},
 		{
 			description: "bad env output",
-			command: testutil.CmdRunOut("minikube docker-env --shell none", `DOCKER_TLS_VERIFY=1
+			command: testutil.CmdRunOut("minikube docker-env --shell none -p minikube", `DOCKER_TLS_VERIFY=1
 DOCKER_HOST`),
 			shouldErr: true,
 		},
 		{
 			description: "command error",
-			command:     testutil.CmdRunOutErr("minikube docker-env --shell none", "", errors.New("fail")),
+			command:     testutil.CmdRunOutErr("minikube docker-env --shell none -p minikube", "", errors.New("fail")),
 			shouldErr:   true,
 		},
 		{
 			description: "minikube exit code 64 - fallback to host docker",
-			command:     testutil.CmdRunOutErr("minikube docker-env --shell none", "", fmt.Errorf("fail: %w", &badUsageErr{})),
+			command:     testutil.CmdRunOutErr("minikube docker-env --shell none -p minikube", "", fmt.Errorf("fail: %w", &badUsageErr{})),
 		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			t.Override(&util.DefaultExecCommand, test.command)
+			t.Override(&cluster.GetClient, func() cluster.Client { return fakeMinikubeClient{} })
 
-			env, _, err := newMinikubeAPIClient("")
+			env, _, err := newMinikubeAPIClient("minikube")
 
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expectedEnv, env)
 		})
@@ -153,3 +156,10 @@ type badUsageErr struct{}
 
 func (e *badUsageErr) Error() string { return "bad usage" }
 func (e *badUsageErr) ExitCode() int { return 64 }
+
+type fakeMinikubeClient struct{}
+
+func (fakeMinikubeClient) IsMinikube(string) bool { return false }
+func (fakeMinikubeClient) MinikubeExec(arg ...string) (*exec.Cmd, error) {
+	return exec.Command("minikube", arg...), nil
+}
