@@ -31,7 +31,6 @@ import (
 	"github.com/moby/buildkit/frontend/dockerfile/shell"
 	"github.com/sirupsen/logrus"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
@@ -64,7 +63,7 @@ var (
 	RetrieveImage = retrieveImage
 )
 
-func readCopyCmdsFromDockerfile(onlyLastImage bool, absDockerfilePath, workspace string, buildArgs map[string]*string, insecureRegistries map[string]bool) ([]fromTo, error) {
+func readCopyCmdsFromDockerfile(onlyLastImage bool, absDockerfilePath, workspace string, buildArgs map[string]*string, cfg Config) ([]fromTo, error) {
 	f, err := os.Open(absDockerfilePath)
 	if err != nil {
 		return nil, err
@@ -82,12 +81,12 @@ func readCopyCmdsFromDockerfile(onlyLastImage bool, absDockerfilePath, workspace
 		return nil, fmt.Errorf("putting build arguments: %w", err)
 	}
 
-	dockerfileLinesWithOnbuild, err := expandOnbuildInstructions(dockerfileLines, insecureRegistries)
+	dockerfileLinesWithOnbuild, err := expandOnbuildInstructions(dockerfileLines, cfg)
 	if err != nil {
 		return nil, err
 	}
 
-	cpCmds, err := extractCopyCommands(dockerfileLinesWithOnbuild, onlyLastImage, insecureRegistries)
+	cpCmds, err := extractCopyCommands(dockerfileLinesWithOnbuild, onlyLastImage, cfg)
 	if err != nil {
 		return nil, fmt.Errorf("listing copied files: %w", err)
 	}
@@ -193,7 +192,7 @@ func expandSrcGlobPatterns(workspace string, cpCmds []*copyCommand) ([]fromTo, e
 	return fts, nil
 }
 
-func extractCopyCommands(nodes []*parser.Node, onlyLastImage bool, insecureRegistries map[string]bool) ([]*copyCommand, error) {
+func extractCopyCommands(nodes []*parser.Node, onlyLastImage bool, cfg Config) ([]*copyCommand, error) {
 	stages := map[string]bool{
 		"scratch": true,
 	}
@@ -215,7 +214,7 @@ func extractCopyCommands(nodes []*parser.Node, onlyLastImage bool, insecureRegis
 			// If `from` references a previous stage, then the `workdir`
 			// was already changed.
 			if !stages[strings.ToLower(from.image)] {
-				img, err := RetrieveImage(from.image, insecureRegistries)
+				img, err := RetrieveImage(from.image, cfg)
 				if err != nil {
 					return nil, err
 				}
@@ -272,6 +271,9 @@ func readCopyCommand(value *parser.Node, envs []string, workdir string) (*copyCo
 
 		paths = append(paths, path)
 	}
+	if len(paths) == 0 {
+		return nil, fmt.Errorf("invalid dockerfile instruction: %q", value.Original)
+	}
 
 	// All paths are sources except the last one
 	var srcs []string
@@ -296,7 +298,7 @@ func readCopyCommand(value *parser.Node, envs []string, workdir string) (*copyCo
 	}, nil
 }
 
-func expandOnbuildInstructions(nodes []*parser.Node, insecureRegistries map[string]bool) ([]*parser.Node, error) {
+func expandOnbuildInstructions(nodes []*parser.Node, cfg Config) ([]*parser.Node, error) {
 	onbuildNodesCache := map[string][]*parser.Node{
 		"scratch": nil,
 	}
@@ -313,7 +315,7 @@ func expandOnbuildInstructions(nodes []*parser.Node, insecureRegistries map[stri
 			var onbuildNodes []*parser.Node
 			if ons, found := onbuildNodesCache[strings.ToLower(from.image)]; found {
 				onbuildNodes = ons
-			} else if ons, err := parseOnbuild(from.image, insecureRegistries); err == nil {
+			} else if ons, err := parseOnbuild(from.image, cfg); err == nil {
 				onbuildNodes = ons
 			} else {
 				return nil, fmt.Errorf("parsing ONBUILD instructions: %w", err)
@@ -331,11 +333,11 @@ func expandOnbuildInstructions(nodes []*parser.Node, insecureRegistries map[stri
 	return expandedNodes, nil
 }
 
-func parseOnbuild(image string, insecureRegistries map[string]bool) ([]*parser.Node, error) {
+func parseOnbuild(image string, cfg Config) ([]*parser.Node, error) {
 	logrus.Tracef("Checking base image %s for ONBUILD triggers.", image)
 
 	// Image names are case SENSITIVE
-	img, err := RetrieveImage(image, insecureRegistries)
+	img, err := RetrieveImage(image, cfg)
 	if err != nil {
 		return nil, fmt.Errorf("retrieving image %q: %w", image, err)
 	}
@@ -379,11 +381,8 @@ func unquote(v string) string {
 	return unquoted
 }
 
-func retrieveImage(image string, insecureRegistries map[string]bool) (*v1.ConfigFile, error) {
-	// TODO: use the proper RunContext
-	localDaemon, err := NewAPIClient(&runcontext.RunContext{
-		InsecureRegistries: insecureRegistries,
-	})
+func retrieveImage(image string, cfg Config) (*v1.ConfigFile, error) {
+	localDaemon, err := NewAPIClient(cfg)
 	if err != nil {
 		return nil, fmt.Errorf("getting docker client: %w", err)
 	}
