@@ -148,10 +148,10 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 		default:
 			if err := r.monitor.Register(
 				func() ([]string, error) {
-					return build.DependenciesForArtifact(ctx, artifact, r.runCtx.GetInsecureRegistries())
+					return build.DependenciesForArtifact(ctx, artifact, r.runCtx)
 				},
 				func(e filemon.Events) {
-					s, err := sync.NewItem(ctx, artifact, e, r.builds, r.runCtx.GetInsecureRegistries())
+					s, err := sync.NewItem(ctx, artifact, e, r.builds, r.runCtx)
 					switch {
 					case err != nil:
 						logrus.Warnf("error adding dirty artifact to changeset: %s", err.Error())
