@@ -717,72 +717,6 @@ func TestValidateJibPluginType(t *testing.T) {
 	}
 }
 
-func TestValidateWorkspaces(t *testing.T) {
-	tmpDir := testutil.NewTempDir(t).Touch("file")
-	tmpFile := tmpDir.Path("file")
-
-	tests := []struct {
-		description string
-		artifacts   []*latest.Artifact
-		shouldErr   bool
-	}{
-		{
-			description: "no workspace",
-			artifacts: []*latest.Artifact{
-				{
-					ImageName: "image",
-				},
-			},
-		},
-		{
-			description: "directory that exists",
-			artifacts: []*latest.Artifact{
-				{
-					ImageName: "image",
-					Workspace: tmpDir.Root(),
-				},
-			},
-		},
-		{
-			description: "error on non-existent location",
-			artifacts: []*latest.Artifact{
-				{
-					ImageName: "image",
-					Workspace: "doesnotexist",
-				},
-			},
-			shouldErr: true,
-		},
-		{
-			description: "error on file",
-			artifacts: []*latest.Artifact{
-				{
-					ImageName: "image",
-					Workspace: tmpFile,
-				},
-			},
-			shouldErr: true,
-		},
-	}
-	for _, test := range tests {
-		testutil.Run(t, test.description, func(t *testutil.T) {
-			// disable yamltags validation
-			t.Override(&validateYamltags, func(interface{}) error { return nil })
-
-			err := Process(
-				&latest.SkaffoldConfig{
-					Pipeline: latest.Pipeline{
-						Build: latest.BuildConfig{
-							Artifacts: test.artifacts,
-						},
-					},
-				})
-
-			t.CheckError(test.shouldErr, err)
-		})
-	}
-}
-
 func TestValidateLogsConfig(t *testing.T) {
 	tests := []struct {
 		prefix    string
